transmission

package module
v0.0.0-...-64ac375 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: CC-BY-4.0 Imports: 4 Imported by: 0

README

transmission

Package transmission is a wrapper around transmission-cli to communicate with the transmission torrent downloader client.

Usage

You need to have Transmission and the Transmission command line interface installed on the same machine as you use this package, otherwise using this package would not make much sense. Probably the cli can also communicate with transmission clients running on another machine but this package has no support for that (yet), simply because I did not need it. Any merge request to add this is welcome.

Known issues

This package works on my FreeBSD system and that is what I made it for. There is preliminary support for other systems but I did not test those.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Add

func Add(hash string, displayname string) error

Add adds the provided torrent hash (magnet) to the transmission torrent download client. The paramater displayname may be an empty string.

func Version

func Version() (string, error)

Version returns the transmission-cli version. Can be used to test the integration.

Types

This section is empty.

Jump to